@@ -25,7 +25,8 @@ from ibm_botocore.client import Config
 from .client_errors import JsonParsingError, MissingValueError, \
     OfCpdPathError, NoWmlInstanceError, WmlServiceNameUnknownTypeError, \
     WmlServiceNameNoPrefixError, WmlServiceCNameNotValidError, \
-    PublicCloudOnlyError, FilesResultsNotSupportedError, NoSuchOverloadError
+    PublicCloudOnlyError, FilesResultsNotSupportedError, NoSuchOverloadError, \
+    WmlUnknownAuthMethodError
 from .cpd_paths import CpdScope
 from .utils import validate_type, \
     get_storage_config_field, get_scope_response_field, get_credentials_field
@@ -125,7 +126,6 @@ class WSPipelines(BaseService):
             disable_ssl_verification=not is_public,
         )
         self.authenticator = authenticator
-        self.apikey = apikey
         self.configure_service(service_name)
         self.is_public = is_public
 
@@ -216,12 +216,18 @@ class WSPipelines(BaseService):
             auth = IAMAuthenticator(apikey, url=iam_url)
         else:
             auth = CloudPakForDataAuthenticator("admin", url=iam_url, apikey=apikey, disable_ssl_verification=True)
+        self.auth_method = AuthMethod.APIKEY
+        # for backwards-compatibility, WSPipelines directly gets the `apikey` field
+        self.apikey = apikey
         return auth, is_public
 
     def _get_authenticator_from_bearer_token(self, bearer_token: str, url: str) -> Tuple[Authenticator, bool]:
         validate_type(bearer_token, "bearer_token", str)
         iam_url, is_public = self._get_iam_url(url)
         auth = BearerTokenAuthenticator(bearer_token=bearer_token)
+        self.auth_method = AuthMethod.BEARER_TOKEN
+        # to stay consistent with `apikey`, WSPipelines directly gets the `bearer_token` field
+        self.bearer_token = bearer_token
         return auth, is_public
 
     @classmethod
@@ -316,17 +322,20 @@ class WSPipelines(BaseService):
             'spaces': self.get_space,
         }
 
-        scope_getter = scope_type_map.get(cpd_scope.scope_type, None)
+        scope_getter = scope_type_map.get(cpd_scope.scope_type(), None)
         if scope_getter is None:
             li = ', '.join(scope_type_map.keys())
             msg = "Handling scopes other than {} is not supported yet!".format(li)
             raise NotImplementedError(msg)
 
-        ctx = cpd_scope.context
+        ctx = cpd_scope.context()
         if ctx == '':
             ctx = None
 
-        scope = scope_getter(cpd_scope.scope_id, context=ctx)
+        if cpd_scope.scope_id() is None:
+            raise RuntimeError("CpdScope in get_scope cannot be query-type")
+
+        scope = scope_getter(cpd_scope.scope_id(), context=ctx)
         return scope
 
     @classmethod
@@ -383,21 +392,30 @@ class WSPipelines(BaseService):
         if data is None:
             raise NoWmlInstanceError(cpd_scope)
 
-        return self._extract_wml_creds_from_computed(data)
+        return self._extract_wml_creds_from_computed(cpd_scope, data)
 
     def _extract_wml_creds_from_computed(
         self,
+        cpd_scope: CpdScope,
         computed: dict
     ) -> 'WmlCredentials':
         guid = get_credentials_field(computed, "guid", str)
         name = get_credentials_field(computed, "name", str)
         crn = get_credentials_field(computed, "crn", str)
         url = self._get_wml_url_from_wml_crn(crn)
+
+        if hasattr(self, 'apikey'):
+            auth = WmlCredentialsApiKey(self.apikey)
+        elif hasattr(self, 'bearer_token'):
+            auth = WmlCredentialsBearerToken(self.bearer_token)
+        else:
+            raise WmlUnknownAuthMethodError(cpd_scope, str(self.auth_method.value))
+
         return WmlCredentials(
             guid = guid,
             name = name,
             url = url,
-            apikey = self.apikey,
+            auth = auth,
         )
 
     def _get_wml_url_from_wml_crn(self, crn: str) -> str:
@@ -509,15 +527,35 @@ class WSPipelines(BaseService):
 
         return response
 
+@attrs(auto_attribs=True, frozen=True)
+class WmlCredentialsAuth:
+    def to_dict(self) -> dict:
+        return attr.asdict(self)
+
+@attrs(auto_attribs=True, frozen=True)
+class WmlCredentialsApiKey(WmlCredentialsAuth):
+    apikey: str
+
+@attrs(auto_attribs=True, frozen=True)
+class WmlCredentialsBearerToken(WmlCredentialsAuth):
+    bearer_token: str
+
 @attrs(auto_attribs=True, kw_only=True, frozen=True)
 class WmlCredentials:
     guid: str
     name: str
     url: str
-    apikey: str
+    auth: WmlCredentialsAuth
 
     def to_dict(self) -> dict:
-        return attr.asdict(self)
+        result = attr.asdict(self)
+
+        # inline `auth` field
+        auth = result['auth']
+        del result['auth']
+        result.update(auth)
+
+        return result
 
 @attrs(auto_attribs=True, kw_only=True, frozen=True)
 class StorageCredentials:
@@ -675,7 +713,7 @@ class CamsClient:
         else:
             value = str(value)
 
-        scope_key = self.scope.scope_type
+        scope_key = self.scope.scope_type()
         if scope_key.endswith('s'):
             scope_key = scope_key[:-1]
         scope_key += '_id'
@@ -684,7 +722,7 @@ class CamsClient:
             "Accept": "application/json",
         }
         params = {
-            scope_key: self.scope.scope_id,
+            scope_key: self.scope.scope_id(),
         }
 
         if self.scope.context is not None and self.scope.context != '':
